***************
Developer Guide
***************

Our project lives on GitHub! Please visit our wiki there to get familiar with developer specific instructions:
`GitHub Cobbler Wiki <https://github.com/cobbler/cobbler/wiki/Developer-guide>`_
